@@ -6,13 +6,13 @@ from .apis import ThreadViewSet, PostViewSet, TopicsViewSet
 
 
 router = routers.DefaultRouter()
-router.register(r'threads', ThreadViewSet, base_name='threads')
-router.register(r'posts', PostViewSet, base_name='posts')
-router.register(r'topics', TopicsViewSet, base_name='topics')
+router.register(r'threads', ThreadViewSet, basename='threads')
+router.register(r'posts', PostViewSet, basename='posts')
+router.register(r'topics', TopicsViewSet, basename='topics')
 
 if getattr(settings, 'REACT_COMMENTS_DJANGO_USE_INTERNAL_USER', None):
     from .apis import UserViewSet
-    router.register(r'users', UserViewSet, base_name='users')
+    router.register(r'users', UserViewSet, basename='users')
 
 # todo import users api if embed
 
